@@ -6,10 +6,14 @@ from libqtile.config import Group
 
 class GroupName(Enum):
     """Enumerated group names"""
-    MAIL = "mail"
-    TERM = "terminal"
+
+    WEB = "web"
+    CHAT = "chat"
+    TERM = "term"
     PERSONAL = "personal"
-    TINKERING = "tinkering"
+    DEV = "dev"
+    TMP = "tmp"
+    CALL = "call"
 
 
-groups = [Group(group.value) for group in list(GroupName)]
+groups = [Group(f"{ix+1}: {group.value}") for ix, group in enumerate(list(GroupName))]
